OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Μετάβαση σε εξέλιξη. Παρακαλούμε περιμένετε μέχρι να ολοκληρωθεί η μετάβαση",
    "Migration started …" : "Η μετάβαση ξεκίνησε ...",
    "Saved" : "Αποθηκεύτηκαν",
    "Not saved" : "Δεν αποθηκεύτηκε",
    "Sending…" : "Γινεται αποστολή...",
    "Email sent" : "Το Email απεστάλη ",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Προέκυψε σφάλμα. Παρακαλούμε μεταφορτώστε ένα πιστοποιητικό PEM κωδικοποιημένο κατά ASCII.",
    "Valid until {date}" : "Έγκυρο έως {date}",
    "Delete" : "Διαγραφή",
    "Local" : "Τοπικά",
    "Private" : "Ιδιωτικά",
    "Only visible to local users" : "Εμφανές μόνο σε τοπικούς χρήστες",
    "Only visible to you" : "Εμφανές μόνο σε εσάς",
    "Contacts" : "Επαφές",
    "Visible to local users and to trusted servers" : "Προσθήκη στη λίστα των έμπιστων διακομιστών",
    "Public" : "Δημόσιο",
    "Will be synced to a global and public address book" : "Θα συγχρονιστεί με παγκόσμιο και δημόσιο βιβλίο διευθύνσεων",
    "Verify" : "Επαλήθευση",
    "Verifying …" : "Γίνεται επαλήθευση ...",
    "Unable to change password" : "Αδυναμία αλλαγής συνθηματικού",
    "Very weak password" : "Πολύ αδύναμο συνθηματικό",
    "Weak password" : "Αδύναμο συνθηματικό",
    "So-so password" : "Μέτριο συνθηματικό",
    "Good password" : "Καλό συνθηματικό",
    "Strong password" : "Δυνατό συνθηματικό",
    "Select a profile picture" : "Επιλογή εικόνας προφίλ",
    "Week starts on {fdow}" : "Η εβδομάδα ξεκινά την {fdow}",
    "Groups" : "Ομάδες",
    "Group list is empty" : "Η λίστα της ομάδας είναι κενή",
    "Unable to retrieve the group list" : "Αδύνατη η ανάκτηση λίστας της ομάδας",
    "{actor} added you to group {group}" : "{actor} σας πρόσθεσε στην ομάδα {group}",
    "You added {user} to group {group}" : "Προσθέσατε τον χρήστη {user} στην ομάδα {group}",
    "{actor} added {user} to group {group}" : "{actor} πρόσθεσε τον χρήστη {user} στην ομάδα {group}",
    "An administrator added you to group {group}" : "Ένας διαχειριστής σάς πρόσθεσε στην ομάδα {group}",
    "An administrator added {user} to group {group}" : "Ένας διαχειριστής πρόσθεσε τον χρήστη {user} στην ομάδα {group}",
    "{actor} removed you from group {group}" : "{actor} σάς αφαίρεσε από την ομάδα {group}",
    "You removed {user} from group {group}" : "Αφαιρέσατε τον χρήστη {user} από την ομάδα {group}",
    "{actor} removed {user} from group {group}" : "{actor} αφαίρεσε τον χρήστη {user} από την ομάδα {group}",
    "An administrator removed you from group {group}" : "Ένας διαχειριστής σάς αφαίρεσε από την ομάδα {group}",
    "An administrator removed {user} from group {group}" : "Ένας διαχειριστής αφαίρεσε τον χρήστη {user} από την ομάδα {group}",
    "{actor} changed your password" : "{actor} το συθηματικό σας άλλαξε",
    "You changed your password" : "Αλλάξατε το συνθηματικό σας",
    "Your password was reset by an administrator" : "Έχει γίνει επαναφορά του συνθηματικού σας από τον διαχειριστή",
    "{actor} changed your email address" : "{actor} άλλαξε τη διεύθυνσή του ηλεκτρονικού ταχυδρομείου σας",
    "You changed your email address" : "Έχετε αλλάξει τη διεύθυνση ηλεκτρονικού ταχυδρομείου σας",
    "Your email address was changed by an administrator" : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας άλλαξε από τον διαχειριστή",
    "Security" : "Ασφάλεια",
    "You successfully logged in using two-factor authentication (%1$s)" : "Έχετε συνδεθεί επιτυχώς με τη χρήση ελέγχου ταυτότητας δύο-παραγόντων (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Μία προσπάθεια σύνδεσης με τη χρήση ελέγχου ταυτότητας δύο-παραγόντων απέτυχε (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ο δικός σας <ισχυρός>κωδικός πρόσβασης</ισχυρός>ή<ισχυρός>αλληλογραφίας</ισχυρός>τροποποιήθηκε",
    "Couldn't remove app." : "Αδυναμία αφαίρεσης εφαρμογής.",
    "Couldn't update app." : "Αδυναμία ενημέρωσης εφαρμογής",
    "Wrong password" : "Εσφαλμένο συνθηματικό",
    "No user supplied" : "Δεν εισήχθη χρήστης",
    "Authentication error" : "Σφάλμα πιστοποίησης",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Παρακαλώ παρέχετε έναν κωδικό ανάκτησης διαχειριστή, διαφορετικά όλα τα δεδομένα χρήστη θα χαθούν.",
    "Wrong admin recovery password. Please check the password and try again." : "Λάθος κωδικός ανάκτησης διαχειριστή. Παρακαλώ ελέγξτε τον κωδικό και δοκιμάστε ξανά.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Το σύστημα δεν υποστηρίζει αλλαγή κωδικού, αλλά το κλειδί κρυπτογράφησης του χρήστη ενημερώθηκε επιτυχώς.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "εγκατάσταση και ενημέρωση εφαρμογών μέσω του καταστήματος εφαρμογών ή του ",
    "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "Το cURL χρησιμοποιεί μια παρωχημένη %1$s έκδοση (%2$s). Παρακαλούμε αναβαθμίστε το λειτουργικό σας σύστημα αλλιώς δυνατότητες όπως %3$s δεν θα δουλέψουν αξιόπιστα.",
    "Invalid SMTP password." : "Μη έγκυρο συνθηματικό SMTP.",
    "Email setting test" : "Δοκιμή ρυθμίσεων email",
    "Well done, %s!" : "Συγχαρητήρια, %s!",
    "If you received this email, the email configuration seems to be correct." : "Εάν λάβατε αυτό το μήνυμα ηλεκτρονικού ταχυδρομείου, ",
    "Email could not be sent. Check your mail server log" : "Το μήνυμα ηλεκτρονικού ταχυδρομείου δεν εστάλη. Ελέγξτε το αρχείο καταγραφής.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Παρουσιάστηκε σφάλμα κατά την αποστολή e-mail. Παρακαλώ ελέγξτε τις ρυθμίσεις σας.(Error: %s)",
    "You need to set your user email before being able to send test emails." : "Πρέπει να ορίσετε το email του χρήστη πριν να είστε σε θέση να στείλετε δοκιμαστικά emails.",
    "Invalid mail address" : "Μη έγκυρη διεύθυνση ταχυδρομείου.",
    "Settings saved" : "Οι ρυθμίσεις αποθηκεύτηκαν",
    "Unable to change full name" : "Δεν ήταν δυνατή η αλλαγή του πλήρους ονόματός σας",
    "Unable to change email address" : "Αδυναμία αλλαγής διεύθυνσης ηλεκτρονικής αλληλογραφίας",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Για να επιβεβαιώσετε τον λογαριασμό σας στο Twitter, δημοσιεύστε την παρακάτω δημοσίευση στο Twitter (σιγουρευτείτε ότι την δημοσιεύετε χωρίς χαρακτήρες αλλαγής γραμμής)",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Για να επιβεβαιώσουμε τον ιστότοπό σας, αποθηκεύστε το κάτωθι περιεχόμενο , στον κατάλογο '.well-known/CloudIdVerificationCode.txt' (παρακαλώ βεβαιωθείτε ότι ολόκληρο το κείμενο υπάρχει σε μια γραμμή):",
    "%1$s changed your password on %2$s." : "%1$sάλλαξε το συνθηματικό σε %2$s.",
    "Your password on %s was changed." : "Ο κωδικός πρόσβασης στο %s έχει αλλάξει.",
    "Your password on %s was reset by an administrator." : "Έχει γίνει επαναφορά του κωδικού πρόσβασης στο %s από τον διαχειριστή.",
    "Password for %1$s changed on %2$s" : "Ο κωδικός πρόσβασης για το %1$s άλλαξε σε %2$s",
    "Password changed for %s" : "Το συνθηματικό άλλαξε για τον %s",
    "If you did not request this, please contact an administrator." : "Εάν δεν το αιτηθήκατε, παρακαλούμε επικοινωνήστε με τον διαχειριστή.",
    "Your email address on %s was changed." : "Η ηλεκτρονική σας διεύθυνση στο %s έχει αλλάξει.",
    "Your email address on %s was changed by an administrator." : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας στο %s άλλαξε από τον διαχειριστή.",
    "Email address for %1$s changed on %2$s" : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου για το %1$s άλλαξε σε %2$s",
    "Email address changed for %s" : "Το συνθηματικό άλλαξε για τον %s",
    "The new email address is %s" : "Η νέα διεύθυνση ηλεκτρονικής αλληλογραφίας είναι %s",
    "Your %s account was created" : "Ο λογαριασμός %s δημιουργήθηκε",
    "Welcome aboard" : "Καλώς ήλθατε",
    "Welcome aboard %s" : "Καλώς ήλθατε %s",
    "Your username is: %s" : "Το όνομα χρήστη σας είναι: %s",
    "Set your password" : "Καθορισμός συνθηματικού",
    "Go to %s" : "Πηγαίνετε στο %s",
    "Install Client" : "Εγκατάσταση πελάτη",
    "Create" : "Δημιουργία",
    "Change" : "Αλλαγή",
    "Share" : "Διαμοιρασμός",
    "Unlimited" : "Απεριόριστο",
    "Verifying" : "Γίνεται επαλήθευση",
    "Nextcloud settings" : "Ρυθμίσεις Nextcloud ",
    "Limit to groups" : "Όριο στις ομάδες",
    "Save changes" : "Αποθήκευση αλλαγών",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Οι επίσημες εφαρμογές αναπτύσσονται μέσα από την κοινότητα. Προσφέρουν κεντρική λειτουργικότητα και είναι έτοιμες για παραγωγική χρήση. ",
    "Official" : "Επίσημο",
    "by" : "από",
    "Remove" : "Αφαίρεση",
    "Disable" : "Απενεργοποίηση",
    "All" : "Όλες",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει ελάχιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει μέγιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Αυτή η εφαρμογή δεν μπορεί να εγκατασταθεί διότι δεν εκπληρώνονται οι ακόλουθες εξαρτήσεις:",
    "View in store" : "Προβολή στο κέντρο εφαρμογών",
    "Visit website" : "Επισκεφθείτε την ιστοσελίδα",
    "Report a bug" : "Αναφέρετε σφάλμα",
    "User documentation" : "Τεκμηρίωση Χρήστη",
    "Admin documentation" : "Τεκμηρίωση Διαχειριστή",
    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
    "No apps found for your version" : "Δεν βρέθηκαν εφαρμογές για αυτή την έκδοση",
    "Enable all" : "Ενεργοποίηση όλων",
    "Enable" : "Ενεργοποίηση",
    "The app will be downloaded from the app store" : "Αυτή η εφαρμογή θα ",
    "Device settings" : "Ρυθμίσεις συσκευής",
    "Rename" : "Μετονομασία",
    "Revoke" : "Ανάκληση",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome για Android",
    "Sync client - {os}" : "Συγχρονισμός πελατών - {os}",
    "This session" : "Αυτή η συνεδρία",
    "Device" : "Συσκευή",
    "Last activity" : "Τελευταία δραστηριότητα",
    "Web, desktop and mobile clients currently logged in to your account." : " ",
    "Error while creating device token" : "Σφάλμα κατά τη δημιουργία διακριτικού συσκευής",
    "Error while deleting the token" : "Σφάλμα κατά την διαγραφή του διακριτικού",
    "App name" : "Όνομα εφαρμογής",
    "Create new app password" : "Δημιουργία νέου συνθηματικού εφαρμογής",
    "Use the credentials below to configure your app or device." : "Χρησιμοποιήστε τα παρακάτω διαπιστευτήρια για να ρυθμίσετε την εφαρμογή ή την συσκευή σας.",
    "For security reasons this password will only be shown once." : "Για λόγους ασφαλείας αυτό το συνθηματικό θα εμφανιστεί μόνο μια φορά.",
    "Username" : "Όνομα χρήστη",
    "Password" : "Συνθηματικό",
    "Done" : "Ολοκληρώθηκε",
    "Copied!" : "Αντιγράφτηκε!",
    "Copy" : "Αντιγραφή",
    "New password" : "Νέο συνθηματικό",
    "Add user in group" : "Προσθήκη χρήστη στην ομάδα",
    "Set user as admin for" : "Ορισμός χρήστη ως διαχειριστή για",
    "Select user quota" : "Επιλογή χωρητικότητας χρήστη",
    "No language set" : "Δεν ορίστηκε γλώσσα",
    "Never" : "Ποτέ",
    "Delete user" : "Διαγραφή χρήστη",
    "Enable user" : "Ενεργοποίηση χρήστη",
    "{size} used" : "{μέγεθος} που χρησιμοποιείται",
    "Welcome mail sent!" : "Απεστάλη το μήνυμα καλωσορίσματος!",
    "Email" : "Ηλεκτρονικό ταχυδρομείο",
    "Group admin for" : "Ομαδα διαχειριστή για",
    "Quota" : "Σύνολο Χώρου",
    "Language" : "Γλώσσα",
    "Storage location" : "Τοποθεσία αποθηκευτικού χώρου",
    "User backend" : "Σύστημα υποστήριξης χρήστη",
    "Last login" : "Τελευταία είσοδος",
    "Add a new user" : "Προσθήκη νέου χρήστη",
    "Default quota" : "Προεπιλέγμενη χωρητικότητα",
    "Your apps" : "Οι εφαρμογές σας",
    "Disabled apps" : "Απενεργοποιημένες εφαρμογές",
    "Updates" : "Ενημερώσεις",
    "App bundles" : "Πακέτα εφαρμογών",
    "Select default quota" : "Επιλογή προεπιλεγμένης χωρητικότητας",
    "Show Languages" : "Εμφάνιση γλωσσών",
    "Show last login" : "Εμφάνιση τελευταιας σύνδεσης",
    "Show user backend" : "Εμφάνιση χρήστη συστήματος υποστήριξης",
    "Admins" : "Διαχειριστές",
    "Everyone" : "Όλοι",
    "Add group" : "Προσθήκη ομάδας",
    "App update" : "Ενημέρωση εφαρμογής",
    "SSL Root Certificates" : "Πιστοποιητικά SSL του Root",
    "Common Name" : "Κοινό Όνομα",
    "Valid until" : "Έγκυρο έως",
    "Issued By" : "Έκδόθηκε από",
    "Valid until %s" : "Έγκυρο έως %s",
    "Import root certificate" : "Εισαγωγή Πιστοποιητικού Root",
    "Administrator documentation" : "Τεκμηρίωση Διαχειριστή",
    "Forum" : "Φόρουμ",
    "None" : "Τίποτα",
    "Login" : "Σύνδεση",
    "Plain" : "Απλό",
    "NT LAN Manager" : "Διαχειριστης NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Διακομιστής Email",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης.",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Είναι σημαντικό ",
    "Send mode" : "Κατάσταση αποστολής",
    "Encryption" : "Κρυπτογράφηση",
    "From address" : "Από τη διεύθυνση",
    "mail" : "ταχυδρομείο",
    "Authentication method" : "Μέθοδος πιστοποίησης",
    "Authentication required" : "Απαιτείται πιστοποίηση",
    "Server address" : "Διεύθυνση διακομιστή",
    "Port" : "Θύρα",
    "Credentials" : "Πιστοποιητικά",
    "SMTP Username" : "Όνομα χρήστη SMTP",
    "SMTP Password" : "Συνθηματικό SMTP",
    "Test email settings" : "Δοκιμή ρυθμίσεων email",
    "Send email" : "Αποστολή email",
    "Security & setup warnings" : "Προειδοποιήσεις ασφάλειας & ρυθμίσεων",
    "All checks passed." : "Όλοι οι έλεγχοι επιτυχείς.",
    "There are some errors regarding your setup." : "Υπάρχουν μερικά σφάλματα σχετικά με τις ρυθμίσεις σας.",
    "Version" : "Έκδοση",
    "Server-side encryption" : "Κρυπτογράφηση από τον Διακομιστή",
    "Enable server-side encryption" : "Ενεργοποίηση κρυπτογράφησης από το διακομιστή",
    "Please read carefully before activating server-side encryption: " : "Παρακαλούμε διαβάστε προσεκτικά πριν ενεργοποιήσετε την κρυπτογράφηση στο διακομιστή:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Μόλις ενεργοποιηθεί η κρυπτογράφηση, όλα τα αρχεία που θα μεταφορτωθούν από αυτό το σημείο και μετά θα κρυπτογραφηθούν στο διακομιστή. Η κρυπτογράφηση είναι δυνατόν να απενεργοποιηθεί αργότερα μόνο αν το ενεργό άρθρωμα κρυπτογράφησης υποστηρίζει αυτή τη λειτουργία και εκπληρούνται όλες οι προϋποθέσεις (πχ ορισμός κλειδιού ανάκτησης).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Η κρυπτογράφηση από μόνη της δεν εγγυάται την ασφάλεια του συστήματος. Για περισσότερες πληροφορίες σχετικά με τον τρόπο λειτουργίας της εφαρμογής κρυπτογράφησης και τις υποστηριζόμενες περιπτώσεις χρήσης, ανατρέξτε στην τεκμηρίωση.",
    "Be aware that encryption always increases the file size." : "Έχετε στο νου σας πως η κρυπτογράφηση πάντα αυξάνει το μέγεθος του αρχείου",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Είναι πάντοτε καλό να δημιουργείτε τακτικά αντίγραφα ασφαλείας των δεδομένων σας, στην περίπτωση της κρυπτογράφησης βεβαιωθείτε ότι έχετε λάβει αντίγραφο ασφαλείας των κλειδιών κρυπτογράφησης παράλληλα με τα δεδομένα σας.",
    "This is the final warning: Do you really want to enable encryption?" : "Αυτή είναι η τελευταία προειδοποίηση: Θέλετε πραγματικά να ενεργοποιήσετε την κρυπτογράφηση;",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Δεν έχει φορτωθεί μονάδα κρυπτογράφησης, παρακαλούμε φορτώστε μια μονάδα κρυπτογράφησης από το μενού εφαρμογών.",
    "Select default encryption module:" : "Επιλογή προεπιλεγμένης μονάδας κρυπτογράφησης:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Πρέπει να μεταφέρετε τα κλειδιά κρυπτογράφησής σας από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια. Παρακαλούμε ενεργοποιήστε την \"Προεπιλεγμένη Μονάδα Κρυπτογράφησης\" και εκτελέστε την εντολή 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Πρέπει να μεταφέρετε τα κλειδιά σας κρυπτογράφησης από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια.",
    "Start migration" : "Έναρξη μετάβασης",
    "Background jobs" : "Εργασίες παρασκηνίου",
    "Pick background job setting" : "Επιλέξτε τη ρύθμιση εργασίας φόντου",
    "Execute one task with each page loaded" : "Εκτελεί μια διεργασία κάθε φορά που φορτώνεται μια σελίδα",
    "The cron.php needs to be executed by the system user \"%s\"." : "Το cron.php πρέπει να εκτελεστεί από τον χρήστη του συστήματος \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Για να τρέξετε αυτό χρειάζεστε την επέκταση PHP POSIX. Δείτε {linkstart} PHP τεκμηρίωση {linked} για περισσότερες λεπτομέρειες.",
    "Sharing" : "Διαμοιρασμός",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ως διαχειριστής μπορείτε να ρυθμίσετε λεπτομερώς την συμπεριφορά διαμοιρασμού.\nΠαρακαλούμε ανατρέξτε στην τεκμηρίωση για περισσότερες πληροφορίες.",
    "Allow apps to use the Share API" : "Επιτρέπει την χρήση του API διαμοιρασμού σε εφαρμογές ",
    "Allow users to share via link" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μέσω συνδέσμου",
    "Allow public uploads" : "Επιτρέπεται το κοινόχρηστο ανέβασμα",
    "Always ask for a password" : "Ερώτηση συνθηματικού πάντα",
    "Enforce password protection" : "Επιβολή προστασίας με κωδικό",
    "Set default expiration date" : "Ορισμός ερήμην ημερομηνίας λήξης",
    "Expire after " : "Λήξη μετά από",
    "days" : "ημέρες",
    "Enforce expiration date" : "Επιβολή της ημερομηνίας λήξης",
    "Allow resharing" : "Επιτρέπεται ο επαναδιαμοιρασμός",
    "Allow sharing with groups" : "Να επιτρέπεται ο διαμοιρασμός με ομάδες",
    "Restrict users to only share with users in their groups" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μόνο με χρήστες που ανήκουν στις ομάδες τους",
    "Exclude groups from sharing" : "Εξαίρεση ομάδων από τον διαμοιρασμό",
    "These groups will still be able to receive shares, but not to initiate them." : "Αυτές οι ομάδες θα συνεχίσουν να λαμβάνουν διαμοιρασμούς, αλλά δεν θα είναι δυνατό να τους δημιουργήσουν.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Να επιτρέπεται η χρήση αυτόματης συμπλήρωσης του ονόματος χρήστη στο πεδίο διαμοιρασμού. Αν η ρύθμιση αυτή είναι απενεργοποιημένη θα πρέπει να εισαχθεί το πλήρες όνομα χρήστη ή το email του. ",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Εμφάνιση κειμένου αποποίησης ευθυνών στη σελίδα δημοσίευσης συνδέσμων. (Εμφανίζεται μόνο όταν η λίστα αρχείων είναι κρυφή.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Αυτό το κείμενο θα ",
    "Like our Facebook page" : "Ακολουθήστε μας στην σελίδα μας στο facebook!",
    "Follow us on Twitter" : "Ακολουθήστε μας στο Twitter",
    "Check out our blog" : "Επισκεφθείτε το ιστολόγιό μας!",
    "Subscribe to our newsletter" : "Εγγραφείτε στο ενημερωτικό δελτίο μας!",
    "Profile picture" : "Φωτογραφία προφίλ",
    "Upload new" : "Μεταφόρτωση νέου",
    "Select from Files" : "Επιλογή από τα Αρχεία",
    "Remove image" : "Αφαίρεση εικόνας",
    "png or jpg, max. 20 MB" : "png ή jpg, μεγ. 20 MB",
    "Picture provided by original account" : "Φωτογραφία που παρέχεται από τον πρωτότυπο λογαριασμό",
    "Cancel" : "Άκυρο",
    "Choose as profile picture" : "Επιλέξτε εικόνα προφίλ",
    "Details" : "Λεπτομέρειες",
    "Full name" : "Πλήρες όνομα",
    "No display name set" : "Δεν ορίστηκε όνομα",
    "Your email address" : "Η διεύθυνση ηλ. ταχυδρομείου σας",
    "No email address set" : "Δεν ορίστηκε διεύθυνση email",
    "For password reset and notifications" : "Για ανάκτηση συνθηματικού και ειδοποιήσεις",
    "Phone number" : "Αριθμός τηλεφώνου",
    "Your phone number" : "Ο αριθμός τηλεφώνου σας",
    "Address" : "Διεύθυνση",
    "Your postal address" : "Ο ταχυδρομικός σας κώδικας",
    "Website" : "Ιστοσελίδα",
    "It can take up to 24 hours before the account is displayed as verified." : "Η επαλήθευση του λογαριασμού μπορεί να διαρκέσει έως και 24 ώρες.",
    "Link https://…" : "Σύνδεσμος https://…",
    "Twitter" : "Twitter",
    "Help translate" : "Βοηθήστε στη μετάφραση",
    "Current password" : "Τρέχων συνθηματικό",
    "Change password" : "Αλλαγή συνθηματικού",
    "Use a second factor besides your password to increase security for your account." : "Χρησιμοποιείστε έναν δεύτερο παράγοντα εκτός του κωδικού πρόσβασης για να αυξήσετε την ασφάλεια του λογαριαμού σας.",
    "Afrikaans (Namibia)" : "Αφρικανικά (Ναμίμπια)",
    "Afrikaans (South Africa)" : "Αφρικανικά (Νότια Αφρική)",
    "Afrikaans" : "Αφρικανικά",
    "Akan (Ghana)" : "Ακάν (Γκάνα)",
    "Akan" : "Ακάν",
    "Albanian (Albania)" : "Αλβανικά (Αλβανία)",
    "Albanian" : "Αλβανικά",
    "Amharic (Ethiopia)" : "Αμχαρικά (Αιθιοπία)",
    "Amharic" : "Αμχαρικά",
    "Arabic (Algeria)" : "Αραβικά (Αλγερία)",
    "Arabic (Bahrain)" : "Αραβικά (Μπαχρέιν)",
    "Arabic (Egypt)" : "Αραβικά (Αίγυπτος)",
    "Arabic (Iraq)" : "Αραβικά (Ιράκ)",
    "Arabic (Jordan)" : "Αραβικά (Ιορδανία)",
    "Arabic (Kuwait)" : "Αραβικά (Κουβέιτ)",
    "Arabic (Lebanon)" : "Αραβικά (Λίβανο)",
    "Arabic (Libya)" : "Αραβικά (Λιβύη)",
    "Arabic (Morocco)" : "Αραβικά (Μαρόκο)",
    "Arabic (Oman)" : "Αραβικά (Ομάν)",
    "Arabic (Qatar)" : "Αραβικά (Κατάρ)",
    "Arabic (Saudi Arabia)" : "Αραβικά (Σαουδική Αραβία)",
    "Arabic (Sudan)" : "Αραβικά (Σουδάν)",
    "Arabic (Syria)" : "Αραβικά (Συρία)",
    "Arabic (Tunisia)" : "Αραβικά (Τυνησία)",
    "English (United Kingdom)" : "Αγγλικά (Ηνωμένο Βασίλειο)",
    "English (United States)" : "Αγγλικά (Η.Π.Α.)",
    "German (Austria)" : "Γερμανικά (Αυστρία)",
    "German (Belgium)" : "Γερμανικά (Βέλγιο)",
    "German (Germany)" : "Γερμανικά (Γερμανία)",
    "German (Liechtenstein)" : "Γερμανικά (Λιχτενστάιν)",
    "German (Luxembourg)" : "Γερμανικά (Λουξεμβούργο)",
    "German (Switzerland)" : "Γερμανικά (Ελβετία)",
    "German" : "Γερμανικά",
    "Store credentials" : "Διαπιστευτήρια αποθήκευσης",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "Το cron.php είναι καταχωρημένο σε μια υπηρεσία webcron ώστε να καλεί το cron.php κάθε 15 λεπτά μέσω HTTP.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συστήματος για να καλέσετε το cron.php αρχείο κάθε 15 λεπτά."
},
"nplurals=2; plural=(n != 1);");
